@@ -154,7 +154,12 @@ def print_root_usage(refresh: bool = False) -> None:
         if official_bucket is None:
             cfg = load_app_config()
             base = official_bucket_base(cfg)
-            official_bucket = {"name": bucket_name, "uri": f"raw::{base}", "priority": 100, "trusted": True}
+            official_bucket = {
+                "name": bucket_name,
+                "uri": f"raw::{base}",
+                "priority": 100,
+                "trusted": True,
+            }
         # usage text cache directory
         ucache_dir = cache_dir() / "usage" / bucket_name
         ucache_dir.mkdir(parents=True, exist_ok=True)
@@ -177,13 +182,30 @@ def print_root_usage(refresh: bool = False) -> None:
                             fetch_to(t, src["url"], timeout=10)
                     out = ""
                     if t.exists():
-                        out = run_usage_for_ps1_capture(t, n) or ""
+                        ignore_policy = bool(official_bucket.get("unsafe-dev-mode"))
+                        result = run_usage_for_ps1_capture(
+                            t,
+                            n,
+                            ignore_execution_policy=ignore_policy,
+                        )
+                        if result.error_kind:
+                            if result.error_kind == "ps5":
+                                cached_text = "PowerShell 5では表示できません"
+                            else:
+                                cached_text = "ヘルプを取得できませんでした。"
+                            if result.error_detail:
+                                debug(
+                                    f"Usage capture error for {n}: {result.error_detail}"
+                                )
+                        else:
+                            cached_text = result.text
+                    else:
+                        cached_text = "ヘルプを取得できませんでした。"
                     # update cache file (even if empty, to avoid repeated fetches)
                     try:
-                        ufile.write_text(out, encoding="utf-8")
+                        ufile.write_text(cached_text, encoding="utf-8")
                     except Exception:
                         pass
-                    cached_text = out
                 # compute first line for table
                 if cached_text:
                     help_line = cached_text.splitlines()[0].strip()
